==> react-native-web-jsonschema-form-2.0.1.tgz: package/widgets/DateWidget.js <==
import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import Datepicker from 'react-native-web-ui-components/Datepicker';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import createDomStyle from 'react-native-web-ui-components/createDomStyle';
import { useOnChange, useOnFocus } from '../utils';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});

const DateWidget = props => {
  const {
    uiSchema,
    onChange,
    name,
    focus,
    value,
    placeholder,
    readonly,
    disabled,
    hasError,
    auto,
    style,
    showCalendarOnFocus
  } = props;
  const onWrappedFocus = useOnFocus(props);
  const onWrappedChange = useOnChange(props);
  const focused = focus === name || focus === null && uiSchema['ui:autofocus'];
  const css = [styles.defaults];
  css.push(auto ? styles.auto : styles.fullWidth);
  css.push(style);
  const className = `DateWidget__${name.replace(/\./g, '-')}`;
  let date = value;

  if (date && date.indexOf('T') >= 0) {
    date = date.split('T')[0].split('-');
    date = `${date[1]}/${date[2]}/${date[0]}`;
    setTimeout(() => onChange(date, name, {
      silent: true
    }));
  }

  return React.createElement(Datepicker, {
    disabled: disabled,
    readonly: readonly,
    hasError: hasError,
    name: name,
    className: className,
    excludeDates: uiSchema['ui:excludeDates'] || null,
    minDate: uiSchema['ui:minDate'] || null,
    maxDate: uiSchema['ui:maxDate'] || null,
    auto: auto,
    date: date,
    onDateChange: onWrappedChange,
    onFocus: onWrappedFocus,
    placeholder: placeholder,
    autoFocus: focused,
    customStyles: {
      input: css
    },
    showCalendarOnFocus: showCalendarOnFocus,
    css: `
        .react-datepicker__input-container input.${className} {
          ${createDomStyle(css)}
        }
      `
  });
};

DateWidget.propTypes = {
  uiSchema: PropTypes.shape().isRequired,
  onChange: PropTypes.func.isRequired,
  name: PropTypes.string.isRequired,
  focus: PropTypes.string,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  placeholder: PropTypes.string,
  readonly: PropTypes.bool,
  disabled: PropTypes.bool,
  hasError: PropTypes.bool,
  auto: PropTypes.bool,
  style: StylePropType,
  showCalendarOnFocus: PropTypes.bool
};
DateWidget.defaultProps = {
  focus: null,
  value: '',
  placeholder: '',
  readonly: false,
  disabled: false,
  hasError: false,
  auto: false,
  style: null,
  showCalendarOnFocus: true
};
export default DateWidget;

==> react-native-web-jsonschema-form-2.0.3.tgz: package/widgets/DateWidget.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import PropTypes from 'prop-types';
import { StyleSheet } from 'react-native';
import Datepicker from 'react-native-web-ui-components/Datepicker';
import StylePropType from 'react-native-web-ui-components/StylePropType';
import createDomStyle from 'react-native-web-ui-components/createDomStyle';
import { useOnChange, useAutoFocus } from '../utils';
const styles = StyleSheet.create({
  defaults: {
    marginBottom: 10
  },
  fullWidth: {
    width: '100%'
  },
  auto: {
    marginBottom: 0
  }
});

const DateWidget = props => {
  const {
    uiSchema,
    onChange,
    name,
    value,
    placeholder,
    readonly,
    disabled,
    hasError,
    auto,
    style,
    showCalendarOnFocus
  } = props;
  const autoFocusParams = useAutoFocus(props);
  const onWrappedChange = useOnChange(props);
  const css = [styles.defaults];
  css.push(auto ? styles.auto : styles.fullWidth);
  css.push(style);
  const className = `DateWidget__${name.replace(/\./g, '-')}`;
  let date = value;

  if (date && date.indexOf('T') >= 0) {
    date = date.split('T')[0].split('-');
    date = `${date[1]}/${date[2]}/${date[0]}`;
    setTimeout(() => onChange(date, name, {
      silent: true
    }));
  }

  return React.createElement(Datepicker, _extends({}, autoFocusParams, {
    disabled: disabled,
    readonly: readonly,
    hasError: hasError,
    name: name,
    className: className,
    excludeDates: uiSchema['ui:excludeDates'] || null,
    minDate: uiSchema['ui:minDate'] || null,
    maxDate: uiSchema['ui:maxDate'] || null,
    auto: auto,
    date: date,
    onDateChange: onWrappedChange,
    placeholder: placeholder,
    customStyles: {
      input: css
    },
    showCalendarOnFocus: showCalendarOnFocus,
    css: `
        .react-datepicker__input-container input.${className} {
          ${createDomStyle(css)}
        }
      `
  }));
};

DateWidget.propTypes = {
  uiSchema: PropTypes.shape().isRequired,
  onChange: PropTypes.func.isRequired,
  name: PropTypes.string.isRequired,
  value: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  placeholder: PropTypes.string,
  readonly: PropTypes.bool,
  disabled: PropTypes.bool,
  hasError: PropTypes.bool,
  auto: PropTypes.bool,
  style: StylePropType,
  showCalendarOnFocus: PropTypes.bool
};
DateWidget.defaultProps = {
  value: '',
  placeholder: '',
  readonly: false,
  disabled: false,
  hasError: false,
  auto: false,
  style: null,
  showCalendarOnFocus: true
};
export default DateWidget;
